@@ -19,13 +19,7 @@ from scipy import interpolate
 from bindata.check_commonprob import check_commonprob, _check_against_simulvals
 from scipy.stats import norm
 
-try:
-    with open(f"{'/'.join(__file__.split('/')[:-1])}/res/simulvals.pickle", 'rb') as f:
-        SimulVals = pickle.load(f)
-except:
-    with open("./bindata/res/SimulVals.pickle", 'rb') as f:
-        SimulVals = pickle.load(f)
-
+from bindata._simuvals_class import SimulVals
 
 def commonprob2sigma(commonprob, simulvals=None):
     """
